Statistics
==========

.. image:: ../../../tests/robotframework/screenshots/statistics.png
   :class: sosse-screenshot
   :scale: 50%

The statistics page shows global information about indexed pages.
